summaryrefslogtreecommitdiff
path: root/web-ui/config/package.sh
diff options
context:
space:
mode:
authorJon Newson <jon_newson@ieee.org>2016-03-15 18:07:42 +1100
committerJon Newson <jon_newson@ieee.org>2016-03-15 18:07:42 +1100
commita455353a811d4cf3a9c327750e9d0fb4c7ee229a (patch)
tree0c42f4a153df882d49b0448209ab0a1937e13685 /web-ui/config/package.sh
parent0ffeb6b70df00a54a2509179c32104bc7f883196 (diff)
parentcf32471caf75b817b23339166002987726d3d6d8 (diff)
Merge branch 'master' of https://github.com/pixelated/pixelated-user-agent
# By Felix Hammerl (13) and Thais Siqueira (3) # Via Christoph (1) and Thais Siqueira (1) * 'master' of https://github.com/pixelated/pixelated-user-agent: Sets SSL certifications to false. Fixes pep8 errors and update requests to 2.9.1. Update locust test to run after xsrf token implementation. Issue #620: Adapt unit tests to CSS changes Issue #620: Refactor palceholder Issue #620: Remove former main css file Issue #620: Spike growl CSS modularization Issue #617: Highlight search terms by altering mail content Issue #617: Allow only >=3 alphanumeric characters in search field Issue #617: Restrict searching to alphanumeric characters Issue #617: Remove highlighting for sandboxed content Issue #617: Add sandbox to build scripts Issue #617: Add sandbox to user-agent Issue #617: Create sandbox resouces Issue #617: Add iframe-resizer Issue #617: Serve content from Sandbox resource
Diffstat (limited to 'web-ui/config/package.sh')
-rw-r--r--web-ui/config/package.sh20
1 files changed, 18 insertions, 2 deletions
diff --git a/web-ui/config/package.sh b/web-ui/config/package.sh
index 9b6bc66c..0bd82367 100644
--- a/web-ui/config/package.sh
+++ b/web-ui/config/package.sh
@@ -28,16 +28,24 @@ mkdir -p dist
./go handlebars
./go imagemin
./go minify_html
+./go minify_sandbox
./go add_git_version
./go buildmain
# copy files
cd app
-cp --parents 404.html fonts/* locales/**/* bower_components/font-awesome/css/font-awesome.min.css bower_components/jquery-file-upload/css/jquery.fileupload.css bower_components/font-awesome/fonts/* ../dist
+cp --parents \
+404.html \
+fonts/* \
+locales/**/* \
+bower_components/font-awesome/css/font-awesome.min.css \
+bower_components/jquery-file-upload/css/jquery.fileupload.css \
+bower_components/font-awesome/fonts/* \
+../dist
cd -
# concat js files and minify
cat \
app/bower_components/modernizr/modernizr.js \
app/bower_components/lodash/dist/lodash.js \
@@ -51,6 +59,14 @@ app/bower_components/foundation/js/foundation.js \
app/bower_components/foundation/js/foundation/foundation.reveal.js \
app/bower_components/foundation/js/foundation/foundation.offcanvas.js \
app/js/foundation/initialize_foundation.js \
+app/bower_components/iframe-resizer/js/iframeResizer.min.js \
.tmp/app.concatenated.js > dist/app.js
node_modules/.bin/minify dist/app.js > dist/app.min.js
rm dist/app.js
+
+# concat js files and minify for sandbox.min.js
+cat \
+app/js/sandbox.js \
+app/bower_components/iframe-resizer/js/iframeResizer.contentWindow.min.js > dist/sandbox.js
+node_modules/.bin/minify dist/sandbox.js > dist/sandbox.min.js
+rm dist/sandbox.js
@@ -28,16 +28,24 @@ mkdir -p dist
cd -
-# concat js files and minify
+# concat js files and minify for app.min.js
cat \
app/bower_components/modernizr/modernizr.js \